import propTypes from 'prop-types';
import React from 'react';
import { ActivityIndicator, TouchableOpacity } from 'react-native';
import { colors, defaultSize, defaultVariant } from '../../../constant/theme';
import { Text } from '../../Atoms';
import styles from './button.style';

const Button = _ref => {
  let {
    title,
    onPress,
    disabled,
    style,
    color,
    loading,
    textColor,
    textSize,
    textStyle
  } = _ref;
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: onPress,
    disabled: disabled,
    style: [styles.buttonDefault, disabled && {
      backgroundColor: colors.grey.grey9
    }, style]
  }, loading ? /*#__PURE__*/React.createElement(ActivityIndicator, {
    color: textColor,
    size: "small"
  }) : /*#__PURE__*/React.createElement(Text, {
    adjustsFontSizeToFit: true,
    numberOfLines: 1,
    text: title,
    size: textSize,
    color: textColor,
    variant: "bold",
    textStyle: textStyle
  }));
};

Button.propTypes = {
  title: propTypes.oneOfType([propTypes.string, propTypes.number]).isRequired,
  size: propTypes.oneOf(defaultSize),
  variant: propTypes.oneOf(defaultVariant),
  onPress: propTypes.func.isRequired
};
Button.defaultProps = {
  title: 'Button Title',
  textSize: 'medium',
  textVariant: 'medium',
  color: colors.primary,
  textColor: colors.grey.white,
  onPress: () => {}
};
export default /*#__PURE__*/React.memo(Button);
//# sourceMappingURL=Button.js.map